==> lighthouse-2.9.1.tgz: package/lighthouse-cli/test/smokehouse/a11y/expectations.js <==
/**
 * @license Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */
'use strict';

/**
 * Expected Lighthouse audit values for byte efficiency tests
 */
module.exports = [
  {
    initialUrl: 'http://localhost:10200/a11y/a11y_tester.html',
    url: 'http://localhost:10200/a11y/a11y_tester.html',
    audits: {
      'accesskeys': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-allowed-attr': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-required-children': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-required-parent': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-roles': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-valid-attr-value': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-valid-attr': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'button-name': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'bypass': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'color-contrast': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'definition-list': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'dlitem': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'document-title': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'duplicate-id': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'frame-title': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'html-has-lang': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'image-alt': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'input-image-alt': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'label': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'layout-table': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'link-name': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'list': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'listitem': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'meta-viewport': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'object-alt': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'tabindex': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'td-headers-attr': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'valid-lang': {
        score: false,
        details: {
          items: {
            length: 1,
          },
        },
      },
    },
  },
];

==> lighthouse-3.1.0.tgz: package/lighthouse-cli/test/smokehouse/a11y/expectations.js <==
/**
 * @license Copyright 2017 Google Inc. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */
'use strict';

/**
 * Expected Lighthouse audit values for byte efficiency tests
 */
module.exports = [
  {
    requestedUrl: 'http://localhost:10200/a11y/a11y_tester.html',
    finalUrl: 'http://localhost:10200/a11y/a11y_tester.html',
    audits: {
      'accesskeys': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-allowed-attr': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-required-children': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-required-parent': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-roles': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-valid-attr-value': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'aria-valid-attr': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'button-name': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'bypass': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'color-contrast': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'definition-list': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'dlitem': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'document-title': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'duplicate-id': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'frame-title': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'html-has-lang': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'image-alt': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'input-image-alt': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'label': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'layout-table': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'link-name': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'list': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'listitem': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'meta-viewport': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'object-alt': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'tabindex': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'td-headers-attr': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
      'valid-lang': {
        score: 0,
        details: {
          items: {
            length: 1,
          },
        },
      },
    },
  },
];
